==> plugin_manager-6.x-1.6.tar.gz: plugin_manager/plugin_manager_search.js <==
// $Id: plugin_manager_search.js,v 1.1.2.11 2008/12/15 16:39:06 joshuarogers Exp $

// Remove all of the rows from a table.
function table_clear(element_id) {
  var table = document.getElementById(element_id);
  try {
    while(table.rows.length > 1) {
      table.deleteRow(table.rows.length-1); 
    }
  } catch(error) {}
}

// Load and display the JSON feed of the queue.
function table_show(table, feed, button_action) {
  $.getJSON(feed, function(data) {
    table_clear(table);
    // Create a new row for every item.
    for (var key in data) {

      // Create a button to remove the item from the queue.
      var button = document.createElement('button');
      button.innerHTML = button_action;
      button.short_name = key;

      button.onclick = function() {
        // Remove from the queue and remove the row from the queue table.
        if (this.innerHTML == 'Remove') {
          queue_remove(this.short_name);
        } else
        {
          queue_add(this.short_name);
        }
        this.parentNode.parentNode.parentNode.removeChild(this.parentNode.parentNode);
      };

      // Add the row to the end of the table.
      var row = document.getElementById(table).insertRow(-1);
      row.insertCell(0).appendChild(button);
      row.insertCell(1).innerHTML = data[key].title;
      row.insertCell(2).innerHTML = data[key].tag;
      row.insertCell(3).innerHTML = data[key].link;
    }
  });
}

function queue_show() {
  table_show('queue', '?q=admin/plugin_manager/search/queue', 'Remove');
}

// Add a plugin to the global install queue.
function queue_add(plugin) {
  table_show('queue', '?q=admin/plugin_manager/search/queue/add/' + plugin, 'Remove');
}

// Remove a plugin from the global install queue.
function queue_remove(plugin) {
  $.get('?q=admin/plugin_manager/search/queue/remove/' + plugin);
}

// Clear the global install queue.
function queue_clear() {
  if (confirm(Drupal.t("Clear Queue: Are you sure?"))) {
    $.get('?q=admin/plugin_manager/search/queue/clear');
    table_clear('queue');
  }
}

function search_letter(letter) {
  table_show('results', '?q=admin/plugin_manager/search/letter/' + letter, 'Add');
}

function search_tag(tag) {
  table_show('results', '?q=admin/plugin_manager/search/tag/' + tag, 'Add');
}

function search_term() {
  var tag = document.getElementById('edit-pmfilter').value;
  var term = document.getElementById('edit-sinput').value;
  table_show('results', '?q=admin/plugin_manager/search/term/' + tag + '/' + term, 'Add');
}

queue_show();

==> plugin_manager-6.x-1.7.tar.gz: plugin_manager/plugin_manager_search.js <==
// $Id: plugin_manager_search.js,v 1.1.2.12 2008/12/18 23:31:10 joshuarogers Exp $

// Remove all of the rows from a table.
function table_clear(element_id) {
  var table = document.getElementById(element_id);
  try {
    while(table.rows.length > 1) {
      table.deleteRow(table.rows.length-1); 
    }
  } catch(error) {}
}

// Load and display the JSON feed of the queue.
function table_show(table, feed, button_action) {
  feed = Drupal.settings.plugin_manager.ajaxPrefix + feed;
  $.getJSON(feed, function(data) {
    table_clear(table);
    // Create a new row for every item.
    for (var key in data) {

      // Create a button to remove the item from the queue.
      var button = document.createElement('button');
      button.innerHTML = button_action;
      button.short_name = key;

      button.onclick = function() {
        // Remove from the queue and remove the row from the queue table.
        if (this.innerHTML == 'Remove') {
          queue_remove(this.short_name);
        } else
        {
          queue_add(this.short_name);
        }
        this.parentNode.parentNode.parentNode.removeChild(this.parentNode.parentNode);
      };

      // Add the row to the end of the table.
      var row = document.getElementById(table).insertRow(-1);
      row.insertCell(0).appendChild(button);
      row.insertCell(1).innerHTML = data[key].title;
      row.insertCell(2).innerHTML = data[key].tag;
      row.insertCell(3).innerHTML = data[key].link;
    }
  });
}

function queue_show() {
  table_show('queue', 'queue', 'Remove');
}

// Add a plugin to the global install queue.
function queue_add(plugin) {
  table_show('queue', 'queue/add/' + plugin, 'Remove');
}

// Remove a plugin from the global install queue.
function queue_remove(plugin) {
  feed = Drupal.settings.plugin_manager.ajaxPrefix + 'queue/remove/' + plugin;
  $.get(feed);
}

// Clear the global install queue.
function queue_clear() {
  if (confirm(Drupal.t("Clear Queue: Are you sure?"))) {
    feed = Drupal.settings.plugin_manager.ajaxPrefix + 'queue/clear';
    $.get(feed);
    table_clear('queue');
  }
}

function search_letter(letter) {
  table_show('results', 'letter/' + letter, 'Add');
}

function search_tag(tag) {
  table_show('results', 'tag/' + tag, 'Add');
}

function search_term() {
  var tag = document.getElementById('edit-pmfilter').value;
  var term = document.getElementById('edit-sinput').value;
  table_show('results', 'term/' + tag + '/' + term, 'Add');
}

queue_show();
